@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2016-01-21'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $DATE = '2016-02-04'; # DATE
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -450,7 +450,9 @@ _
                     } keys %$args_prop) {
                     my $arg_spec = $args_prop->{$arg};
                     my $cs = $arg_spec->{cmdline_src};
-                    my $type = Data::Sah::Util::Type::get_type($arg_spec->{schema} // '');
+                    my $sch = $arg_spec->{schema} // '';
+                    $sch = $sch->[1]{of} if $arg_spec->{stream} && $sch->[0] eq 'array';
+                    my $type = Data::Sah::Util::Type::get_type($sch);
                     next unless $cs;
                     if ($cs eq 'stdin_line') {
                         # XXX support stdin_line, cmdline_prompt, is_password (for disabling echo)
@@ -814,7 +816,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.34 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2016-01-21.
+This document describes version 0.35 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2016-02-04.
 
 =head1 SYNOPSIS
 
